@@ -1,18 +1,44 @@
 package Apache::AuthenSmb;
 
 use strict;
-use Apache::Constants ':common';
+#use Apache::Constants ':common';
 use Authen::Smb;
 
-$Apache::AuthenSmb::VERSION = '0.50';
+$Apache::AuthenSmb::VERSION = '0.70';
 
+############################################
+# here is where we start the new code....
+############################################
+use mod_perl ;
+
+# use Apache::Constants qw(:common);
+# setting the constants to help identify which version of mod_perl
+# is installed
+use constant MP2 => ($mod_perl::VERSION >= 1.99);
+
+# test for the version of mod_perl, and use the appropriate libraries
+BEGIN {
+        if (MP2) {
+                require Apache::Const;
+                require Apache::Access;
+                require Apache::Connection;
+                require Apache::Log;
+                require Apache::RequestRec;
+                require Apache::RequestUtil;
+                Apache::Const->import(-compile => 'HTTP_UNAUTHORIZED','OK');
+        } else {
+                require Apache::Constants;
+                Apache::Constants->import('HTTP_UNAUTHORIZED','OK');
+        }
+}
+##################### end modperl code ######################
 
 sub handler {
     my $r = shift;
     my($res, $sent_pwd) = $r->get_basic_auth_pw;
     return $res if $res; #decline if not Basic
 
-    my $name = $r->connection->user;
+    my $name = MP2 ? $r->user : $r->connection->user;
 
     my $pdc = $r->dir_config('myPDC');
     my $bdc = $r->dir_config('myBDC') || $pdc;
@@ -20,14 +46,14 @@ sub handler {
 
     if ($name eq "") {
 	$r->note_basic_auth_failure;
-        $r->log_reason("Apache::AuthenSmb - No Username Given", $r->uri);
-        return AUTH_REQUIRED;
+        MP2 ? $r->log_error("Apache::AuthenSmb - No Username Given", $r->uri) : $r->log_reason("Apache::AuthenSmb - No Username Given", $r->uri);
+        return MP2 ? Apache::HTTP_UNAUTHORIZED : Apache::Constants::HTTP_UNAUTHORIZED;
     }
 
     if (!$pdc) {
 	$r->note_basic_auth_failure;
-        $r->log_reason("Apache::AuthenSmb - Configuration error, no PDC", $r->uri);
-        return AUTH_REQUIRED;
+        MP2 ? $r->log_error("Apache::AuthenSmb - Configuration error, no PDC", $r->uri) : $r->log_reason("Apache::AuthenSmb - Configuration error, no PDC", $r->uri);
+         return MP2 ? Apache::HTTP_UNAUTHORIZED : Apache::Constants::HTTP_UNAUTHORIZED;
     }
 
     my $return = Authen::Smb::authen($name,
@@ -38,40 +64,40 @@ sub handler {
 
     unless($return == 0) {
 	$r->note_basic_auth_failure;
-	$r->log_reason("user $name: password mismatch", $r->uri);
-	return AUTH_REQUIRED;
+	MP2 ? $r->log_error("user $name: password mismatch", $r->uri) : $r->log_reason("user $name: password mismatch", $r->uri);
+	 return MP2 ? Apache::HTTP_UNAUTHORIZED : Apache::Constants::HTTP_UNAUTHORIZED;
     }
 
     unless (@{ $r->get_handlers("PerlAuthzHandler") || []}) {
 	$r->push_handlers(PerlAuthzHandler => \&authz);
     }
 
-    return OK;
+    return MP2 ? Apache::OK : Apache::Constants::OK;
 }
 
 sub authz {
     my $r = shift;
     my $requires = $r->requires;
-    return OK unless $requires;
+    return (MP2 ? Apache::OK : Apache::Constants::OK) unless $requires;
 
-    my $name = $r->connection->user;
+    my $name = MP2 ? $r->user : $r->connection->user;
 
     for my $req (@$requires) {
         my($require, @rest) = split /\s+/, $req->{requirement};
 
 	#ok if user is one of these users
 	if ($require eq "user") {
-	    return OK if grep $name eq $_, @rest;
+	    return (MP2 ? Apache::OK : Apache::Constants::OK) if grep $name eq $_, @rest;
 	}
 	#ok if user is simply authenticated
 	elsif ($require eq "valid-user") {
-	    return OK;
+	    return MP2 ? Apache::OK : Apache::Constants::OK;
 	}
     }
     
     $r->note_basic_auth_failure;
     $r->log_reason("user $name: not authorized", $r->uri);
-    return AUTH_REQUIRED;
+     return MP2 ? Apache::HTTP_UNAUTHORIZED : Apache::Constants::HTTP_UNAUTHORIZED;
 
 }
 
@@ -122,7 +148,8 @@ people there are that need this type of functionality.
 
 =head1 AUTHOR
 
-Michael Parker <parkerm@null.net>
+Michael Parker <parkerm@pobox.com>
+Ported by Shannon Eric Peevey <speeves@unt.edu>
 
 =head1 COPYRIGHT
 
